[dests] Fix hipTestClock, hipTestNew & hipTestGlobalVariable tests for nvcc

nvcc does not support global kernels in struct/class

Change-Id: I2d7297e0c3725564215e20dbdd31c0bb8d7a07de
Этот коммит содержится в:
Maneesh Gupta
2018-09-17 15:32:05 +05:30
родитель 7066147760
Коммит f63ffaf6e5
3 изменённых файлов: 8 добавлений и 19 удалений
+1 -4
Просмотреть файл
@@ -33,8 +33,6 @@ THE SOFTWARE.
#define LEN 512
#define SIZE 2048
struct TestClock {
static __global__ void kernel1(int* Ad) {
int tid = threadIdx.x + blockIdx.x * blockDim.x;
Ad[tid] = clock() + clock64() + __clock() + __clock64();
@@ -61,9 +59,8 @@ struct TestClock {
assert(0 != A[i]);
}
}
};
int main() {
TestClock().run();
run();
passed();
}